OC.L10N.register(
    "mail",
    {
    "Auto detect failed. Please use manual mode." : "L'autodeteccion a fracassat. Utilizatz lo mòde manual.",
    "Creating account failed: " : "La creacion del compte a fracassat :",
    "Mail" : "Mail",
    "Name" : "Nom",
    "Mail Address" : "Adreça mail",
    "Password" : "Senhal",
    "None" : "Pas cap",
    "IMAP Password" : "Senhal IMAP",
    "SMTP Password" : "Senhal SMTP",
    "Save" : "Salvar",
    "Connect" : "Connectar",
    "Write message …" : "Escriure un messatge…",
    "Sending …" : "Mandadís ...",
    "Go back" : "Revenir en arrière",
    "Message sent!" : "Messatge mandat !",
    "Send" : "Mandar",
    "Choose a file to add as attachment" : "Causissètz un fichièr de jónher al messatge",
    "Choose" : "Causir",
    "Favorites" : "Favorits",
    "Other" : "Autre",
    "Select" : "Select",
    "Move" : "Move",
    "Delete" : "Suprimir",
    "Choose a folder to store the attachment in" : "Causissètz lo dorsièr dins lo qual enregistrar la pèça junta",
    "Settings" : "Paramètres",
    "Cancel" : "Anullar",
    "Mark all as read" : "Marcar totes coma legits",
    "Clear cache" : "Voidar l'escondedor",
    "Reply" : "Respondre",
    "General" : "Generals",
    "User" : "User",
    "Keyboard shortcut" : "Acorchis de clavièr",
    "Keyboard shortcuts" : "Acorchis de clavièr",
    "Search" : "Recercar",
    "Refresh" : "Refrescar",
    "All" : "Tot",
    "Archive" : "Archius",
    "Drafts" : "Borrolhons",
    "All inboxes" : "Totas las bóstias",
    "Inbox" : "Bóstia de recepcion",
    "Junk" : "Indesirables",
    "Sent" : "Mandats",
    "Trash" : "Escobilhièr",
    "Error while sharing file" : "Error pendent lo partiment del fichièr",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Error loading message" : "Error al moment del cargament del messatge",
    "Continue to %s" : "Contunhar cap a %s"
},
"nplurals=2; plural=(n > 1);");
